//-----------------------------------------------------------------------------
/** @file libpentobi_base/PlayerBase.cpp
    @author Markus Enzenberger
    @copyright GNU General Public License version 3 or later */
//-----------------------------------------------------------------------------

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "PlayerBase.h"

namespace libpentobi_base {

//-----------------------------------------------------------------------------

PlayerBase::~PlayerBase() = default;

bool PlayerBase::resign() const
{
    return false;
}

//-----------------------------------------------------------------------------

} // namespace libpentobi_base
